@@ -197,7 +197,6 @@ def swap_parts_of_speech(text1, text2, parts_of_speech=['ADJ', 'NOUN']) -> (str,
     text2 = ''.join([text2_word_swaps.get(token.text_with_ws, token.text_with_ws) for token in doc2])
     return text1, text2
 
-
 def markov(input: input_type, ngram_size=1, num_output_sentences=5) -> List[str]:
     """Markov chain text generation from markovify library, supports custom n-gram length
 
@@ -214,8 +213,9 @@ def markov(input: input_type, ngram_size=1, num_output_sentences=5) -> List[str]
         markov_models.append(markovify.Text(text, state_size=ngram_size))
     textgen = markovify.combine(markov_models)
     output_sentences = []
+    sentence_starters = [sentence.split(' ')[0] for sentence in sentences]
     while len(output_sentences) < num_output_sentences:
-        sentence = textgen.make_sentence()
+        sentence = textgen.make_sentence_with_start()
         if isinstance(sentence, str):
             output_sentences.append(sentence)
     return output_sentences
